@@ -33,5 +33,8 @@ class Bridge(ABC):
 
     @traceback
     def close(self):
-        if self.window:
-            self.window.destroy()
+        try:
+            if self.window:
+                self.window.destroy()
+        except Exception as ex:  # pylint: disable=W0703
+            self.logger.error("There was an exception trying to close window: %s", ex)
