@@ -50,34 +50,31 @@ class RecorderBridge(BrowserBridge):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self._current_url: Optional[str] = None
-        self._recorded_operations: List[RecordedOperation] = []
+        self._recorded_operation: Union[RecordedOperation, None] = None
 
     @traceback
-    def start_recording(self) -> List[RecordedOperation]:
-        # TODO: Handle as async in future instead of blocking
-        self.logger.debug("Starting recording...")
+    def start_recording(self) -> Union[RecordedOperation, None]:
+        self.logger.debug("Starting recording event...")
         self._record()
-        self.logger.debug("Recorded events: %s", self._recorded_operations)
-        return self._recorded_operations
+        self.logger.debug("Recorded event: %s", self._recorded_operation)
+        return self._recorded_operation
 
     @traceback
-    def stop_recording(self) -> List[RecordedOperation]:
-        # TODO: Handle as async in future instead of blocking
-        self.logger.debug("Stopping recording...")
-        self.driver.stop_recording()
-        return self._recorded_operations
+    def stop_recording(self) -> Union[RecordedOperation, None]:
+        self.web_driver.stop_recording()
+        self.logger.debug("Recording should stop...")
+        return self._recorded_operation
 
     @traceback
     def show_guide(self):
-        self.driver.show_guide("recording-guide")
+        self.web_driver.show_guide("recording-guide")
 
     def _record(self):
-        self._recorded_operations = []
-        while True:
-            # TODO: Could we try catch the page change?
+        for attempt_number in range(3):
+            self.logger.debug("Recording attempt: %s", attempt_number)
             try:
                 self._wait_for_page_to_load()
-                event: RecordEvent = self.driver.record_event()
+                event: RecordEvent = self.web_driver.record_event()
                 self.logger.debug("Raw event: %s", event)
             except JavascriptException as exc:
                 self.logger.debug("Ignoring Javascript exception: %s", exc)
@@ -86,6 +83,7 @@ class RecorderBridge(BrowserBridge):
                     "list": [],
                     "url": self._current_url,
                 }
+                continue
             except TimeoutException:
                 self.logger.debug("Retrying after script timeout")
                 event: RecordEvent = {
@@ -93,15 +91,19 @@ class RecorderBridge(BrowserBridge):
                     "list": [],
                     "url": self._current_url,
                 }
+                continue
 
             if not event:
                 self.logger.error("Received empty event: %s", event)
                 continue
 
-            if not self._handle_event(event):
+            if self._handle_event(event):
                 return
+        self._handle_stop_event("force stop")
 
     def _handle_event(self, event: RecordEvent) -> bool:
+        self._recorded_operation = None
+
         event_type = event["actionType"]
         event_url = event["url"]
 
@@ -111,53 +113,55 @@ class RecorderBridge(BrowserBridge):
             message: RecordedOperation = {
                 "path": None,
                 "time": None,
-                "meta": None,
+                "meta": [],
                 "selectors": [],
                 "type": "comment",
                 "value": f"Recorder detected that URL changed to {event_url}",
                 "trigger": "unknown",
             }
             self._current_url = event_url
-            self._recorded_operations += [message]
+            self._recorded_operation = message
+
         if event_type == "exception":
             self.logger.debug("Event(s) is an exception: %s", event)
-            return True  # Ignore errors for now
         elif event_type == "event":
             self.logger.debug("Received event(s) from page: %s", event["list"])
-            self._recorded_operations += self._get_valid_ops(event=event)
-            return True
+            self._recorded_operation = self._get_valid_ops(event=event)
         elif event_type == "stop":
-            self.logger.debug("Received stop from page")
-            self.driver.stop_recording()
-            self._recorded_operations += event["list"]
-            return False
+            self._handle_stop_event(event_url=event_url)
         else:
             raise ValueError(f"Unknown event type: {event_type}")
 
+        return True
+
+    def _handle_stop_event(self, event_url):
+        self.logger.debug("Received stop from page")
+        message: RecordedOperation = {
+            "path": None,
+            "time": None,
+            "meta": [],
+            "selectors": [],
+            "type": "command",
+            "value": f"Received stop from: {event_url}",
+            "trigger": "stop",
+        }
+        self.web_driver.stop_recording()
+        self._recorded_operation = message
+
     def _get_valid_ops(self, event: RecordEvent):
-        valid_ops = []
+        self.logger.debug("Valid operations: %s", event["list"])
         for operation in event["list"]:
             if "selectors" not in operation or len(operation["selectors"]) == 0:
                 continue
             valid_selectors = []
-            valid_metas = []
             for selector in operation["selectors"]:
-                meta = self.validate(
-                    strategy=selector["strategy"],
-                    value=selector["value"],
-                    hide_highlights=True,
-                )
-                if "matches" not in meta or len(meta["matches"]) == 0:
-                    self.logger.error("Selector %s was NOT valid: %s", selector, meta)
-                    continue
-                valid_selectors.append(selector)
-                valid_metas.append(meta)
-                self.logger.debug("Raw event metadata for %s: %s", selector, meta)
+                self.logger.debug("Raw event selector: %s", selector)
+                if selector is not None:
+                    valid_selectors.append(selector)
             operation["selectors"] = valid_selectors
-            operation["meta"] = valid_metas
             if len(valid_selectors) > 0:
-                valid_ops.append(operation)
-        return valid_ops
+                return operation
+        return None
 
     def set_window_height(self, height):
         self.logger.debug(
@@ -176,8 +180,13 @@ class RecorderBridge(BrowserBridge):
         self.window.resize(local_width, local_height)
 
     def _wait_for_page_to_load(self):
-        waiter = WebDriverWait(self.driver, 10)
-        waiter.until(
-            lambda x: x.selenium.execute_script("return document.readyState")
-            == "complete"
-        )
+        try:
+            waiter = WebDriverWait(self.web_driver, 10)
+            waiter.until(
+                lambda x: x.selenium.execute_script("return document.readyState")
+                == "complete"
+            )
+        except Exception as ex:  # pylint: disable=W0703
+            self.logger.debug(
+                "There was an exception while waiting for page to load: %s", ex
+            )
