@@ -43,6 +43,11 @@ class WindowsBridge(DatabaseMixin, Bridge):
         self.logger.info("Saving %s as locator: %s", name, locator)
         return super().save(name, locator)
 
+    @traceback
+    def stop(self):
+        self.logger.debug("Destroying window...")
+        self.close()
+
     def set_window_height(self, height):
         self.logger.debug(
             "Content sizes: %s (height) x %s (width)",
