@@ -1,7 +1,6 @@
 import base64
 import logging
 import os
-import platform
 import signal
 import traceback
 from pathlib import Path, WindowsPath
@@ -19,6 +18,7 @@ from selenium.common.exceptions import (  # type: ignore
     WebDriverException,
 )
 from selenium.webdriver import ChromeOptions, Remote  # type: ignore
+from selenium.webdriver.common.by import By
 
 
 def load_resource(filename):
@@ -139,7 +139,7 @@ class WebDriver:
                 desired_capabilities={},
             )
             driver.session_id = session_id
-            driver.switch_to_window(handle)
+            driver.switch_to.window(handle)
         finally:
             Remote.execute = execute
 
@@ -191,7 +191,10 @@ class WebDriver:
         self.logger.debug("Resources loaded!")
 
     def _exec_resources(self):
-        if not self.selenium.find_elements_by_id("inspector-style"):
+        try:
+            self.selenium.find_element(by=By.ID, value="inspector-style")
+        except Exception as ex:  # pylint: disable=broad-except
+            self.logger.debug("Inspector was not injected. Exception: %s", ex)
             self.logger.debug("Injecting resources to web page...")
             self.selenium.execute_script(self.resources["inspector"])
             self.logger.debug("[DONE] Inspector code injected!")
@@ -236,7 +239,7 @@ class WebDriver:
         )
 
     def _init_driver(self):  # noqa: C901
-        browsers = webdriver.DRIVER_PREFERENCE[platform.system()]
+        browsers = webdriver.get_browser_order()
         for browser in browsers:
             if browser == "Chrome":
                 kwargs = {"chrome_options": chrome_options()}
@@ -253,14 +256,6 @@ class WebDriver:
                     return webdriver.start(browser, **kwargs)
 
             try:
-                # Try to use webdriver already in cache
-                cache = webdriver.cache(browser)
-                if cache:
-                    try:
-                        return _create_driver(cache)
-                    except Exception:  # pylint: disable=broad-except
-                        pass
-
                 # Try to download webdriver
                 download = webdriver.download(browser)
                 if download:
@@ -278,19 +273,19 @@ class WebDriver:
     def _to_finder(self, strategy):
         strategy = str(strategy).lower()
         finder = {
-            "class": self.selenium.find_elements_by_class_name,
-            "css": self.selenium.find_elements_by_css_selector,
-            "id": self.selenium.find_elements_by_id,
-            "link": self.selenium.find_elements_by_link_text,
-            "name": self.selenium.find_elements_by_name,
-            "tag": self.selenium.find_elements_by_tag_name,
-            "xpath": self.selenium.find_elements_by_xpath,
+            "class": By.CLASS_NAME,
+            "css": By.CSS_SELECTOR,
+            "id": By.ID,
+            "link": By.LINK_TEXT,
+            "name": By.NAME,
+            "tag": By.TAG_NAME,
+            "xpath": By.XPATH,
         }[strategy]
 
         if not finder:
             raise ValueError(f"Unknown search strategy: {strategy}")
 
-        return finder
+        return lambda val: self.selenium.find_elements(by=finder, value=val)
 
     def start(self):
         if self.selenium:
@@ -434,7 +429,7 @@ callback(tags);
             self._is_recording = True
             self._exec_resources()
 
-            result = self.selenium.execute_async_script(
+            result = self._exec_async_script(
                 "var callback = arguments[arguments.length - 1];"
                 "Inspector.recordEvent(callback);"
             )
@@ -450,7 +445,7 @@ callback(tags);
     def stop_recording(self) -> None:
         try:
             if self._is_recording:
-                self.selenium.execute_script("Inspector.stopRecording();")
+                self._exec_async_script("Inspector.stopRecording();")
         except Exception as ex:  # pylint: disable=W0703
             self.logger.error("There was an exception while recording event: %s", ex)
         self._is_recording = False
